# Security Package for Drupal

## Overview
The Security Package is a comprehensive solution for enhancing your Drupal site's security posture. It installs essential security modules and establishes a properly formatted security.txt file, following security best practices for Drupal 10 and 11 sites.

## Features

### Security Modules
- **Flood Control**: Configure per-form and per-IP flood control limits to prevent brute force attacks
- **Two-Factor Authentication (TFA)**: Add an extra layer of security for user authentication
- **Security Kit (SecKit)**: Implement security hardening options including CSP, XSS protection, and clickjacking prevention
- **Security Review**: Automate security reviews of your Drupal configuration
- **SecKit Override**: Custom module to extend and override Security Kit configuration as needed

### Security.txt Implementation
Automatically installs a [security.txt](https://securitytxt.org/) file in the `.well-known` directory, making it easier for security researchers to report vulnerabilities.

## Installation

1. Add this recipe to your Drupal project:
   Run the following command in your terminal:

   ```composer require drupal/security_recipe```

2. Run the installation command:
   To install the security recipe, use the following Drush command in your terminal:

   ```drush recipe recipes/security_recipe```

   This command will install and enable all the necessary modules and apply the default configurations.

3. Configure the security settings according to your site's requirements:
   After installation, you'll need to review and adjust the security settings to match your site's specific needs. Here are the key areas to configure:

   a. Flood Control:
   - Navigate to /admin/config/system/flood-control in your Drupal admin panel.
   - Adjust the rate limits and user limits for contact forms and logins as needed.

   b. Two-Factor Authentication (TFA):
   - Go to /admin/config/people/tfa to set up TFA.
   - Configure which user roles require TFA and set up the preferred validation methods.

   c. Security Kit (SecKit):
   - Access /admin/config/system/seckit to fine-tune security options.
   - Review and adjust the Content Security Policy, XSS protection, and other security headers.

   d. Security Review:
   - Run an initial security review at /admin/reports/security-review.
   - Address any findings or recommendations provided by the review.

   e. Security.txt:
   - Locate the security.txt file in your Drupal root's .well-known directory.
   - Update the file with your actual security contact information and policies.

   Remember to test each security feature after configuration to ensure it's working as expected. Regularly review and update these settings as your site's needs evolve.

## Default Configuration

### Flood Control
- Contact form rate limit: 3 attempts
- Contact form user limit: 5 attempts
- Login rate limit: 5 attempts
- Login user limit: 5 attempts

### Two-Factor Authentication
- Enabled by default for administrator and editor roles
- TOTP (Time-based One-Time Password) as default validation method
- Configurable time skew and site naming options

### Security Kit
- Content Security Policy (CSP) enforced with reasonable defaults
- XSS protection enabled
- CSRF origin checking enabled
- Clickjacking protection with JavaScript/CSS/noscript fallbacks

## Post-Installation Steps

After installation, the following steps will automatically be performed:
1. Drupal cache rebuild
2. Initial security review scan
3. SecKit enabled at the system level

## Next Steps

1. **Update security.txt**: Replace placeholder emails and URLs with your actual security contact information
2. **Configure 2FA**: Set up two-factor authentication for your administrative users
3. **Run security review**: Review the initial security scan and address any findings
4. **Review SecKit settings**: Fine-tune the Content Security Policy and other SecKit settings according to your site's needs

## Requirements
- Drupal 10 or 11
- Administrative access to the Drupal site
